@@ -1,37 +1,44 @@
 /*
-    Copyright (C) 2013 by Ashwin Rajeev<ashwin_rajeev@hotmail.com>
+    SPDX-FileCopyrightText: 2013 Ashwin Rajeev <ashwin_rajeev@hotmail.com>
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "gameview.h"
 
-#include <KgSound>
-#include <QGraphicsObject>
-#include <KMessageBox>
-#include <KLocalizedString>
-
+// game
 #include "globals.h"
 #include "settings.h"
+// KDEGames
+#include <kdegames_version.h>
+#include <KgSound>
+// KF
+#include <KMessageBox>
+#include <KLocalizedContext>
+#include <KLocalizedString>
+// Qt
+#include <QGraphicsObject>
+#include <QQmlContext>
+
 
 GameView::GameView(QWidget *parent) :
-    KgDeclarativeView(parent),
+    QQuickWidget(parent),
     grid(new AbstractGrid),
     m_provider(new KgThemeProvider)
 {
+    QQmlEngine *engine = this->engine();
+
+    auto *localizedContextObject = new KLocalizedContext(engine);
+    engine->rootContext()->setContextObject(localizedContextObject);
+
+    setResizeMode(SizeRootObjectToView);
+
+#if KDEGAMES_VERSION >= QT_VERSION_CHECK(7, 4, 0)
+    m_provider->discoverThemes(QStringLiteral("themes"));
+#else
     m_provider->discoverThemes("appdata", QStringLiteral("themes"));
-    m_provider->setDeclarativeEngine(QStringLiteral("themeProvider"), engine());
+#endif
+    m_provider->setDeclarativeEngine(QStringLiteral("themeProvider"), engine);
     m_soundTurn = new KgSound(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/turn.wav")), this);
     m_soundClick = new KgSound(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/click.wav")), this);
     m_soundConnect = new KgSound(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/connect.wav")), this);
@@ -84,7 +91,7 @@ void GameView::clicked(int index)
 {
     if (index >= 0) {
         rotatingCells.insert(index);
-        emit rotationStarted();
+        Q_EMIT rotationStarted();
         if (Settings::playSounds()) {
             m_soundTurn->start();
         }
@@ -106,11 +113,11 @@ void GameView::rotated(int index, int angle)
     case 180: case -180:
         grid->cellAt(index)->invert();
     }
-    QList<int> changedCells = grid->updateConnections();
+    const QList<int> changedCells = grid->updateConnections();
     bool newTerminalConnected = false;
     rotatingCells.remove(index);
 
-    foreach (int i, changedCells) {
+    for (int i : changedCells) {
         if(grid->cellAt(i)->isTerminal()){
             newTerminalConnected = true;
         }
@@ -125,7 +132,7 @@ void GameView::rotated(int index, int angle)
     }
 
     if (Settings::autolock()) {
-        emit lock(index);
+        Q_EMIT lock(index);
     }
     if (rotatingCells.count() == 0) {
         checkCompleted();
@@ -165,7 +172,7 @@ void GameView::checkCompleted()
             return;
         }
     }
-    emit gameOver(QLatin1String("won"));
+    Q_EMIT gameOver(QLatin1String("won"));
 }
 
 void GameView::solve()
@@ -183,7 +190,7 @@ void GameView::solve()
             setSprite(i, code, QLatin1String("none"));
         }
     }
-    emit gameOver(QLatin1String("solved"));
+    Q_EMIT gameOver(QLatin1String("solved"));
 }
 
 void GameView::updateSettings()
